@@ -12,6 +12,7 @@ export.sc_smd <- function(object, caption = NA, footnote = NA,
                           kable_styling_options = list(), 
                           kable_options = list(), 
                           round = 2,
+                          decimals = 2,
                           flip = FALSE,
                           ...) {
   
@@ -43,9 +44,9 @@ export.sc_smd <- function(object, caption = NA, footnote = NA,
   
   if (isTRUE(flip)) {
     cases <- out$Case
-    out[-2:-1] <- round(out[-2:-1], round)
+    out[-1] <- round(out[-1], round)
     names_par <- colnames(out)[-1]
-    out <- t(out[-2:-1]) |> as.data.frame()
+    out <- t(out[-1]) |> as.data.frame()
     out <- cbind(Statistic = rownames(out), out)
     colnames(out) <- c("Statistic", cases)
   }
@@ -55,7 +56,9 @@ export.sc_smd <- function(object, caption = NA, footnote = NA,
     kable_options, 
     kable_styling_options, 
     caption = caption,
-    footnote = footnote
+    footnote = footnote,
+    decimals = decimals,
+    ...
   )
   
   if (!is.na(filename)) .save_export(table, filename)
