@@ -18,6 +18,11 @@ options(
 
 res <- list()
 
+res$pipe <- " |> "
+res$pipe_br <- paste0(res$pipe, "\n")
+
+# choices ------
+
 res$choices <- list()
 examples <- data(package = "scan")$results[, 3]
 filter <- startsWith(examples,"Grosche2014") | 
@@ -52,6 +57,13 @@ set_xlabel("Session", color = "darkred")',
 
 )
 
+res$choices$scplot_templates_annotate <- c(
+  "",
+  "Marks" = 'add_marks(case = "all", position = \"values < mean(values)\", shape = 16, size = 2)',
+  "Text" = 'add_text("Hallo", case = 1, x = 5, y = 20)',
+  "Arrow" = 'add_arrow(case = 1, 2, 70, 6, 55, color = "darkred")'
+)  
+
 themes <- names(scplot:::.scplot_themes)
 
 for(i in seq_along(themes)) {
@@ -66,6 +78,7 @@ res$choices$fn_stats <- c(
   "Data trends" = "trend",
   "Auto correlations" = "autocorr",
   "Piecewise regression" = "plm",
+  "Multivariate piecewise regression" = "mplm",
   "Hierarchical piecewise regression" = "hplm",
   "Conservative Dual-Criterion" = "cdc",
   "Tau U" = "tau_u",
@@ -74,11 +87,41 @@ res$choices$fn_stats <- c(
   "Percent exceeding the median" = "pem",
   "Percent exceeding the trend" = "pet",
   "Percentage of all non-overlapping data" = "pand",
+  "Improvement rate difference" = "ird",
   "Nonoverlap of all Pairs" = "nap",
   "Randomization test" = "rand_test",
   "Outlier analysis" = "outlier"
 )
 
+.name <- function(x, at, label) {
+  names(x)[which(x == at)] <- label
+  x
+}
+
+
+res$choices$pt_method <- names(scan:::.opt$mc_fun)  |> 
+  setNames(names(scan:::.opt$mc_fun)) |> 
+  .name("plm_level", "Regression (level effect)") |> 
+  .name("plm_slope", "Regression (slope effect)") |> 
+  .name("plm_poisson_level", "Regression (level effect; frequencies)") |> 
+  .name("plm_poisson_slope", "Regression (slope effect; frequencies)") |> 
+  .name("hplm_level", "Multilevel-regression (level effect)") |> 
+  .name("hplm_slope", "Multilevel-regression (slope effect)") |> 
+  .name("tauU", "Tau-U (trend A)") |>
+  .name("tauU_slope", "Tau-U (trend A and B)") |>
+  .name("tauU_meta", "Metaanalysis Tau-U (trend A)") |>
+  .name("tauU_slope_meta", "Metaanalysis Tau-U (trend A and B)") |>
+  .name("base_tau", "Baseline corrected tau") |>
+  .name("rand", "Randomization test") |> 
+  .name("rand_decrease", "Randomization test (decreasing)") |> 
+  .name("rand_slope", "Randomization test slope") |>
+  .name("rand_slope_decrease", "Randomization test slope (decreasing)")
+
+
+
+
+# placeholder ----
+
 res$placeholder$values <- "Enter values here to create a new case. E.g. \nA = 1,2,3,4,3 \nB = 7,6,7,8,7,6"
 
 res$placeholder$transform <- 'e.g.
@@ -88,6 +131,8 @@ values2 = values - max(values[phase=="A"])
 across_cases(values2 = scale(values)
 '
 
+res$placeholder$stats_out_args <- "e.g.: decimals = 3; meta = FALSE"
+
 res$placeholder$plot_arguments <- '(choose one or more of the templates below and experiment with the syntax here.)
 '
 
@@ -97,12 +142,36 @@ res$placeholder$variables <-
 "(optional, e.g., depression = 1,4,3,5,6,5,7
 separate multiple variables with linebreaks)"
 
+res$placeholder$pt <- "Power calculation may take some time. Click 'Run' to start calculation."
+
+# div ------
+
+res$div$settings <- paste0(
+  "background-color:#f0f0f0; ",
+  "border: 1px solid black; border-radius: 5px; ",
+  "padding-left: 10px; padding-right: 10px; ",
+  "padding-top: 0px; padding-bottom: 0px; "
+)
+
+res$div$pt <- paste0(
+  "background-color:#f0f0f0; ",
+  "border: 1px solid black; border-radius: 5px; ",
+  "padding-left: 5px; padding-right: 5px; ",
+  "padding-top: 0px; padding-bottom: 0px; "
+)
+
+# error ----
+
 res$error_msg$invalid_case <- "Sorry!
 The last case you tried to add didn't have a valid case definition."
 
 res$error_msg$plot <- "Sorry!
 The plot arguments are not valid."
 
+res$error_msg$scdf_save <- "Sorry!
+The last file you saved is corrupt. Did you forget to add a case before saving?"
+
+# msg ----
 
 res$msg$startup <-
 "Welcome to 'shiny scan'!
@@ -110,8 +179,8 @@ res$msg$startup <-
 You can:
 
 1. create a new case (fill in 'values' and click 'Add')
-2. load a dataset (click 'Load file' to import an rds, csv, or excel file)
-3. choose an example scdf (choose from 'Load example')
+2. load a dataset (Data -> Load -> click 'Open file' to import an rds, csv, or excel file)
+3. choose an example scdf (Data -> Load -> choose from 'Choose example')
 
 'exampleABC' is a good place to start.
 
@@ -131,8 +200,8 @@ res$msg$no_case_scdf <-
 "No case has been defined yet.
 You can:
 1. create a new case (fill in 'values' and click 'Add')
-2. load a dataset (click 'Load file' to import an rds, csv, or excel file)
-3. choose an example scdf (from 'Load example')
+2. load a dataset (Data -> Load -> click 'Open file' to import an rds, csv, or excel file)
+3. choose an example scdf (Data -> Load -> 'Choose example')
 "
 
 res$msg$no_case <-
@@ -140,6 +209,8 @@ res$msg$no_case <-
 Please define a case on the 'Data' tab first.
 "
 
+res$msg$load_page <- "Please choose an example scdf or open a file in rds, xlsx, csv, or R-code format."
+
 res$help_page <- structure(
   "<h4 id=\"welcome-to-shiny-scan\">Welcome to <em><strong>shiny scan</strong></em>!</h4>
   <p><em>Shiny-scan</em> is a graphical surface for <em>scan</em> (Single-Case Data Analysis). <em>scan</em> is an R package.</p>
